==============================
 Invenio-OAuthClient v1.0.0a13
==============================

Invenio-OAuthClient v1.0.0a13 was released on May 05, 2017.

About
-----

Invenio module that provides OAuth web authorization support.

*This is an experimental developer preview release.*

What's new
----------

- Refactoring for Invenio 3.

Installation
------------

   $ pip install invenio-oauthclient==1.0.0a13

Documentation
-------------

   http://invenio-oauthclient.readthedocs.io/

Happy hacking and thanks for flying Invenio-OAuthClient.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-oauthclient
|   URL: http://inveniosoftware.org
